package com.ruoyi.project.VRdemo.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.excel.EasyExcel;
import com.ruoyi.common.utils.excel.ExcelReadUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.project.VRdemo.domain.imData.ConsultationImData;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.VRdemo.domain.Consultation;
import com.ruoyi.project.VRdemo.service.IConsultationService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 博雅集南洋资讯检索Controller
 *
 * @author ruoyi
 * @date 2024-09-26
 */
@RestController
@RequestMapping("/vr/consultation")
public class ConsultationController extends BaseController {

    private final IConsultationService consultationService;

    public ConsultationController(@Autowired IConsultationService consultationService) {
        this.consultationService = consultationService;
    }

    /**
     * 查询博雅集南洋资讯检索列表
     */
    @Anonymous
    @GetMapping("/list")
    public AjaxResult list(Consultation consultation) {
        return consultationService.selectConsultationListByMenu(consultation);
    }

    /**
     * 查询分页列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping("/pageList")
    public TableDataInfo pageList(Consultation consultation) {
        startPage();
        List<Consultation> list = consultationService.selectConsultationList(consultation);
        return getDataTable(list);
    }

    /**
     * 获取博雅集南洋资讯检索详细信息
     */
    @Anonymous
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(consultationService.selectConsultationById(id));
    }

    /**
     * 新增博雅集南洋资讯检索
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "博雅集南洋资讯检索", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Consultation consultation) {
        return toAjax(consultationService.insertConsultation(consultation));
    }

    /**
     * 修改博雅集南洋资讯检索
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "博雅集南洋资讯检索", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Consultation consultation) {
        return toAjax(consultationService.updateConsultation(consultation));
    }

    /**
     * 删除博雅集南洋资讯检索
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "博雅集南洋资讯检索", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(consultationService.deleteConsultationByIds(ids));
    }

    /**
     * 导出博雅集南洋资讯检索列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "博雅集南洋资讯检索", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Consultation consultation) {
        List<Consultation> list = consultationService.selectConsultationList(consultation);
        ExcelUtil<Consultation> util = new ExcelUtil<>(Consultation.class);
        util.exportExcel(response, list, "博雅集南洋资讯检索数据");
    }

    /**
     * 下载导入模板
     */
    @Anonymous
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) throws IOException {
        List<ConsultationImData> dataList = new ArrayList<>();
        EasyExcel.write(response.getOutputStream(), ConsultationImData.class).sheet("Sheet1").doWrite(dataList);
    }

    /**
     * 导入数据
     */
    @Anonymous
    @PostMapping("/import")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws IOException {

        List<Consultation> list = ExcelReadUtil.read(file, ConsultationImData.class, Consultation.class);

        // 调用服务层方法进行数据导入处理
        String message = consultationService.importData(list, updateSupport);

        // 返回成功响应，携带导入结果信息
        return AjaxResult.success(message);
    }
}
