package com.ruoyi.project.VRdemo.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.framework.config.ServerConfig;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.VRdemo.domain.NoteData;
import com.ruoyi.project.VRdemo.domain.vo.NoteDataVo;
import com.ruoyi.project.VRdemo.service.INoteDataService;
import org.apache.commons.io.FilenameUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;

/**
 * @ClassName NoteDataController
 * @Description TODO
 * @Author zhixian li
 * @Date 2023年07月17日 16:33
 * @Version 1.0
 */
@RestController
@RequestMapping("/system/data")
public class NoteDataController extends BaseController {
    @Autowired
    private INoteDataService noteDataService;
    @Autowired
    private ServerConfig serverConfig;

    /**
     * 查询文档管理列表
     */
//    @PreAuthorize("@ss.hasPermi('system:data:list')")
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping("/list")
    public TableDataInfo list(NoteData noteData) {
        Long companyId = getLoginUser().getCompanyId();
        noteData.setCompanyId(companyId);
        startPage();

        System.out.println(noteData.toString());
        List<NoteData> list = noteDataService.selectNoteDataList(noteData);
        return getDataTable(list);
    }

    @Anonymous
    @PostMapping("/reading")
    public AjaxResult LoadingApp(@RequestBody JSONObject jsonObject) {
        Long companyAppId = Long.parseLong(jsonObject.getString("company_app_id"));
        Long dataType = Long.parseLong(jsonObject.getString("data_type"));

        StpUtil.login(companyAppId);
        NoteDataVo noteDataVo = new NoteDataVo();
        noteDataVo.setCompanyId(companyAppId);
        noteDataVo.setDataType(dataType);

        List<NoteData> list = noteDataService.selectNoteDataListVo(noteDataVo);
        if (list == null || list.size() == 0) {
            AjaxResult.error("获取数据失败");
        }

        AjaxResult ajax = AjaxResult.success();
        ajax.put("data", list);

        return ajax;
    }

    /**
     * 导出文档管理列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "文档管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, NoteData noteData) {
        List<NoteData> list = noteDataService.selectNoteDataList(noteData);
        ExcelUtil<NoteData> util = new ExcelUtil<NoteData>(NoteData.class);
        util.exportExcel(response, list, "文档管理数据");
    }

    /**
     * 获取文档管理详细信息
     */
//    @PreAuthorize("@ss.hasPermi('system:data:query')")
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(noteDataService.selectNoteDataById(id));
    }

    /**
     * 新增文档管理
     */
//    @PreAuthorize("@ss.hasPermi('system:data:add')")
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "文档管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody NoteData noteData) {
        //获取编号为00的文件路径
        String pathStr = noteData.getPath();
        if(StringUtils.isNull(pathStr)){
            return error("上传文件不能为空");
        }
        String[] paths = pathStr.split(","); //将批量文件名转化为数组
        String zero = "";
        for (String s : paths) {
            String fileName = s.substring(s.lastIndexOf("/") + 1, s.lastIndexOf(".")); //获取文件名
            String last = fileName.substring(fileName.length() - 2); //获取文件名后面的编号
            if (last.equals("01")) {
                zero = s;
            }
            if (last.equals("00")) {
                zero = s;
                break;
            }
        }
        noteData.setPath(zero);
        int count = paths.length;//获取上传文件数量
        noteData.setCount((long) count);

        if (!noteDataService.checkUserNameUnique(noteData)) {
            return error("新增标题'" + noteData.getTitle() + "'失败，该标题已存在");
        }
        Long companyId = getLoginUser().getCompanyId();
        noteData.setCompanyId(companyId);
        return toAjax(noteDataService.insertNoteData(noteData));
    }

    @Anonymous
    @PostMapping("addNote")
    public AjaxResult addNote(@RequestBody NoteData noteData) {
//        Long companyId =getLoginUser().getCompanyId();
        noteData.setCompanyId(3L);
        return toAjax(noteDataService.insertNoteData(noteData));
    }

    /**
     * 通用上传请求（单个）
     */
    @PostMapping("/upload")
    public AjaxResult uploadFile(MultipartFile file) throws Exception {
        try {
            String extension = FilenameUtils.getExtension(file.getOriginalFilename());
            String filePath;

            if (extension.equalsIgnoreCase("pdf")) {
                filePath = RuoYiConfig.getuploadPdf();
            } else if (extension.equalsIgnoreCase("doc") || extension.equalsIgnoreCase("docx")) {
                filePath = RuoYiConfig.getuploadWord();
            } else {
                filePath = RuoYiConfig.getUploadPath();
            }

            String fileName = FileUploadUtils.upload(filePath, file);
            String url = serverConfig.getUrl() + fileName;

            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileName);
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());

            NoteData noteData = new NoteData();
            noteData.setPath(url);
            noteDataService.updateNoteData(noteData);
            return ajax;
        } catch (Exception e) {
            return AjaxResult.error(e.getMessage());
        }
    }

    /**
     * 修改文档管理
     */
//    @PreAuthorize("@ss.hasPermi('system:data:edit')")
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "文档管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody NoteData noteData) {
        return toAjax(noteDataService.updateNoteData(noteData));
    }

    //删除
    @DeleteMapping("/{ids}")
    public String deleteFile(@PathVariable("ids") String ids) {
        try {
            Long Ids = Long.parseLong(ids);
            System.out.println(Ids);
            boolean success = noteDataService.deleteFile(Ids);
            if (success) {
                return "文件删除成功.";
            } else {
                return "文件删除失败.";
            }
        } catch (NumberFormatException e) {
            return "文件格式错误";
        }
    }
}
