package com.ruoyi.project.VRdemo.domain.imData;

import com.alibaba.excel.annotation.ExcelIgnore;
import com.alibaba.excel.annotation.ExcelProperty;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.excel.DataConverter;
import com.ruoyi.project.VRdemo.domain.Thesis;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

public class ThesisImData implements BaseImData<ThesisImData, Thesis> {

    @ExcelProperty("序号")
    private Long id;

    @ExcelProperty("作者姓名")
    private String name;

    @ExcelProperty("指导教师")
    private String teacher;

    @ExcelProperty("专业")
    private String major;

    @ExcelProperty("题名")
    private String title;

    @ExcelProperty("关键词")
    private String keyword;

    //    @JsonFormat(pattern = "yyyy")
    @ExcelProperty("答辩时间")
    private String replyTime;

    @ExcelProperty("学位")
    private String degree;

    @ExcelProperty("排序")
    private Integer sort;

    private static Date getDate(String replyTime) {
        Date finalDate;
        try {
            // 根据输入字符串的长度选择合适的日期格式
            SimpleDateFormat sdfInput;
            if (replyTime.contains(".")) {
                sdfInput = new SimpleDateFormat("yyyy.M");
            } else {
                sdfInput = new SimpleDateFormat("yyyy");
            }

            // 设置lenient为false以进行严格的解析
            sdfInput.setLenient(false);
            // 解析日期字符串
            Date date = sdfInput.parse(replyTime);
            // 创建Calendar实例并设置年份和月份
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(date);
            // 设置日期为每个月的第一天
            calendar.set(Calendar.DAY_OF_MONTH, 1);
            // 获取最终的日期
            finalDate = calendar.getTime();
        } catch (ParseException e) {
            throw new RuntimeException("无法解析日期字符串: " + replyTime, e);
        }
        return finalDate;
    }

    @ExcelIgnore
    DataConverter<ThesisImData, Thesis> converter = new DataConverter<ThesisImData, Thesis>() {
        @Override
        protected Thesis convert(ThesisImData thesisImData) {
            Date finalDate = null;
            if (!StringUtils.isEmpty(thesisImData.getReplyTime())) {
                finalDate = getDate(thesisImData.getReplyTime());
            }

            Thesis thesis = new Thesis();
            thesis.setId(thesisImData.getId());
            thesis.setName(thesisImData.getName());
            thesis.setTeacher(thesisImData.getTeacher());
            thesis.setMajor(thesisImData.getMajor());
            thesis.setTitle(thesisImData.getTitle());
            thesis.setKeyword(thesisImData.getKeyword());
            thesis.setReplyTime(finalDate);
            thesis.setDegree(thesisImData.getDegree());
            thesis.setSort(thesisImData.getSort());
            return thesis;
        }
    };

    @Override
    public DataConverter<ThesisImData, Thesis> getConverter() {
        return converter;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getReplyTime() {
        return replyTime;
    }

    public void setReplyTime(String replyTime) {
        this.replyTime = replyTime;
    }

    public String getDegree() {
        return degree;
    }

    public void setDegree(String degree) {
        this.degree = degree;
    }

    public String getKeyword() {
        return keyword;
    }

    public void setKeyword(String keyword) {
        this.keyword = keyword;
    }

    public String getMajor() {
        return major;
    }

    public void setMajor(String major) {
        this.major = major;
    }

    public String getTeacher() {
        return teacher;
    }

    public void setTeacher(String teacher) {
        this.teacher = teacher;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }
}
