package com.ruoyi.project.VRdemo.mapper;

import com.ruoyi.project.VRdemo.domain.*;
import com.ruoyi.project.VRdemo.domain.imData.NoticeImData;
import com.ruoyi.project.VRdemo.domain.imData.StudyImData;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;
import java.util.Map;

@Mapper
public interface DataExcelMapper {
    /**
     * 获取导出的应用数据列表，用于从数据存储中获取要导出的应用数据。
     *
     * @return 导出的应用数据列表
     */
    List<ExportApp> getAppData();

    /**
     * 批量插入数据列表，用于将多个导入的应用数据插入到数据存储中。
     *
     * @param dataList 导入的应用数据列表
     */
    void insertAppDataList(List<ImportApp> dataList);

    /**
     * 更新导入的应用数据，用于更新已存在的应用记录。
     *
     * @param app 要更新的应用数据
     * @return 受影响的行数，表示更新操作是否成功
     */
    public int updateImApp(ImportApp app);

    /**
     * 根据标题查询导入的应用数据，用于检查是否存在相同标题的记录。
     *
     * @param titleAsLong 标题作为唯一标识
     * @return 查询到的应用数据，如果不存在返回null
     */
    //App selectAppByTitle(String titleAsLong);

    /**
     * 获取活动预告导出数据列表，用于从数据存储中获取要导出的活动预告数据。
     *
     * @return 活动预告导出数据列表
     */
    List<NoticeExData> getNoticeData();

    /**
     * 根据活动预告的开展方式值，获取对应的开展方式标签（硬编码方式）。
     *
     * @param holdingType 活动预告的开展方式值
     * @return 对应的开展方式标签
     */
    default String getHoldingTypeLabel(Integer holdingType) {
        if (holdingType == 1) {
            return "线上";
        } else if (holdingType == 2) {
            return "线下";
        } else if (holdingType == 3) {
            return "线上线下相结合";
        } else {
            return "未知";
        }
    }

    /**
     * 批量插入活动预告数据列表，将给定的活动预告数据列表批量插入到数据存储中。
     *
     * @param dataList 活动预告数据列表
     */
    void insertNoticeDataList(List<NoticeImData> dataList);

    /**
     * 更新活动预告数据，根据活动预告标题进行更新操作。
     *
     * @param notice 活动预告数据对象
     * @return 更新操作影响的行数
     */
    public int updateImNotice(NoticeImData notice);

    /**
     * 根据活动预告标题，从数据存储中查询并返回相应的活动预告数据对象。
     *
     * @param titleAsLong 活动预告标题
     * @return 活动预告数据对象
     */
    NoticeImData selectNoticeByTitle(String titleAsLong);

    /**
     * 获取活研究管理导出数据列表，用于从数据存储中获取要导出的数据。
     *
     * @return 研究导出数据列表
     */
    List<StudyExData> getStudyData();

    /**
     * 根据字典类型获取字典数据列表
     *
     * @param dictType 字典类型
     * @return 字典数据列表，每个元素是一个 Map，包含 dict_value 和 dict_label
     */
    @Select("SELECT dict_value, dict_label FROM sys_dict_data WHERE dict_type = #{dictType}")
    List<Map<String, String>> getDictDataByType(String dictType);

    /**
     * 批量插入活动预告数据列表，将给定的活动预告数据列表批量插入到数据存储中。
     *
     * @param dataList 活动预告数据列表
     */
    void insertStudyDataList(List<StudyImData> dataList);

    /**
     * 更新活动预告数据，根据活动预告标题进行更新操作。
     *
     * @param study 活动预告数据对象
     * @return 更新操作影响的行数
     */
    public int updateImStudy(StudyImData study);

    /**
     * 根据研究标题
     *
     * @param titleAsLong 研究标题
     * @return 研究数据对象
     */
    StudyImData selectStudyByTitle(String titleAsLong);

    @Select("SELECT dict_value FROM sys_dict_data WHERE dict_type = #{dictType} AND dict_label = #{dictLabel}")
    String findValueByLabel(@Param("dictType") String dictType, @Param("dictLabel") String dictLabel);

}