package com.ruoyi.project.VRdemo.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.project.VRdemo.domain.Economy;
import com.ruoyi.project.VRdemo.domain.LibraryMenu;
import com.ruoyi.project.VRdemo.mapper.LibraryMenuMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.EconomyMapper;
import com.ruoyi.project.VRdemo.service.IEconomyService;

/**
 * 东南亚经济统计Service业务层处理
 *
 * @author ruoyi
 * @date 2024-10-06
 */
@Service
public class EconomyServiceImpl implements IEconomyService {

    private final EconomyMapper economyMapper;

    private final LibraryMenuMapper libraryMenuMapper;

    public EconomyServiceImpl(@Autowired EconomyMapper economyMapper,
                              @Autowired LibraryMenuMapper libraryMenuMapper) {
        this.economyMapper = economyMapper;
        this.libraryMenuMapper = libraryMenuMapper;
    }

    /**
     * 查询东南亚经济统计
     *
     * @param id 东南亚经济统计主键
     * @return 东南亚经济统计
     */
    @Override
    public Economy selectEconomyById(Long id) {
        return economyMapper.selectEconomyById(id);
    }

    /**
     * 查询东南亚经济统计列表
     *
     * @param economy 东南亚经济统计
     * @return 东南亚经济统计
     */
    @Override
    public List<Economy> selectEconomyList(Economy economy) {
        return economyMapper.selectEconomyList(economy);
    }

    /**
     * 查询东南亚经济统计列表
     *
     * @param economy 东南亚经济统计
     * @return 东南亚经济统计集合
     */
    @Override
    public AjaxResult selectEconomyListByMenu(Economy economy) {
        LibraryMenu parentMenu = libraryMenuMapper.selectLibraryMenuByModule("economy");
        List<LibraryMenu> menuList = libraryMenuMapper.selectChildMenuListById(parentMenu.getId());
        AjaxResult data = new AjaxResult();
        for (LibraryMenu menu : menuList){
            List<Economy> economies = economyMapper.selectEconomyListByAffiliation(menu.getTitle());
            data.put(menu.getTitle(), economies);
        }

        return data;
    }

    /**
     * 新增东南亚经济统计
     *
     * @param economy 东南亚经济统计
     * @return 结果
     */
    @Override
    public int insertEconomy(Economy economy) {
        economy.setCreateTime(DateUtils.getNowDate());
        return economyMapper.insertEconomy(economy);
    }

    /**
     * 修改东南亚经济统计
     *
     * @param economy 东南亚经济统计
     * @return 结果
     */
    @Override
    public int updateEconomy(Economy economy) {
        economy.setUpdateTime(DateUtils.getNowDate());
        return economyMapper.updateEconomy(economy);
    }

    /**
     * 批量删除东南亚经济统计
     *
     * @param ids 需要删除的东南亚经济统计主键
     * @return 结果
     */
    @Override
    public int deleteEconomyByIds(Long[] ids) {
        return economyMapper.deleteEconomyByIds(ids);
    }

    /**
     * 删除东南亚经济统计信息
     *
     * @param id 东南亚经济统计主键
     * @return 结果
     */
    @Override
    public int deleteEconomyById(Long id) {
        return economyMapper.deleteEconomyById(id);
    }

    /**
     * 导入数据
     *
     * @param dataList      数据列表
     * @param updateSupport 是否更新
     * @return 结果
     */
    @Override
    public String importData(List<Economy> dataList, boolean updateSupport) {
        BulkImportService<Economy> importService = new BulkImportService<Economy>() {
            @Override
            protected Long checkExistingItem(Economy item) {
                Economy economy = economyMapper.selectEconomyByTitle(item.getTitle());
                return economy == null ? 0L : economy.getId();
            }

            @Override
            protected boolean updateItem(Economy item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return economyMapper.updateEconomy(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<Economy> batchDataList) {
                return economyMapper.insertEconomyDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(Economy item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
